;; Generated package description from excorporate.el  -*- no-byte-compile: t -*-
(define-package "excorporate" "1.1.1.0.20230529.173200" "Exchange Web Services (EWS) integration" '((emacs "24.1") (cl-lib "0.6.1") (fsm "0.2.1") (soap-client "3.2.0") (url-http-ntlm "2.0.4") (nadvice "0.3") (url-http-oauth "0.8.3")) :commit "a6617dea1f9c3af8a4d8a20a53f5b265455b8e96" :authors '(("Thomas Fitzsimmons" . "fitzsim@fitzsim.org")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("calendar") :url "https://www.fitzsim.org/blog/")
